==> haskell-microaeson-0.1.0.1-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microaeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 microaeson
version:              0.1.0.1
visibility:           public
id:                   microaeson-0.1.0.1-FRDFcOEoZIvAvpn9DcymFg
key:                  microaeson-0.1.0.1-FRDFcOEoZIvAvpn9DcymFg
license:              GPL-3.0-only
maintainer:           Andreas Abel
author:               Herbert Valerio Riedel
synopsis:             A tiny JSON library with light dependency footprint
description:
    @microaeson@ aims to provide a [RFC 8259](https://tools.ietf.org/html/rfc8259) compliant JavaScript Object Notation (JSON) implementation.
    The [microaeson](https://hackage.haskell.org/package/microaeson) package provides a smaller subset of the [aeson](https://hackage.haskell.org/package/aeson) API with less dependencies and a simpler implementation.

    The API is designed in such a way to allow to easily convert client code written against @microaeson@'\''s API to use the full [aeson](https://hackage.haskell.org/package/aeson) API.

category:             Text, Web, JSON
abi:                  56e359233de92b76cdc0d8b67858525f
exposed:              True
exposed-modules:      Data.Aeson.Micro
hidden-modules:       Data.Aeson.Micro.Parser Data.Aeson.Micro.Scanner
import-dirs:          /usr/lib/ghc-9.0.2/site-local/microaeson-0.1.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/microaeson-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microaeson
hs-libraries:         HSmicroaeson-0.1.0.1-FRDFcOEoZIvAvpn9DcymFg
depends:
    array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    deepseq-1.4.5.0 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-microaeson/html/microaeson.haddock
haddock-html:         /usr/share/doc/haskell-microaeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microaeson-0.1.0.1-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microaeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 microaeson
version:              0.1.0.1
visibility:           public
id:                   microaeson-0.1.0.1-LwBFehKKOqM1ikuDRDjv1D
key:                  microaeson-0.1.0.1-LwBFehKKOqM1ikuDRDjv1D
license:              GPL-3.0-only
maintainer:           Andreas Abel
author:               Herbert Valerio Riedel
synopsis:             A tiny JSON library with light dependency footprint
description:
    @microaeson@ aims to provide a [RFC 8259](https://tools.ietf.org/html/rfc8259) compliant JavaScript Object Notation (JSON) implementation.
    The [microaeson](https://hackage.haskell.org/package/microaeson) package provides a smaller subset of the [aeson](https://hackage.haskell.org/package/aeson) API with less dependencies and a simpler implementation.

    The API is designed in such a way to allow to easily convert client code written against @microaeson@'\''s API to use the full [aeson](https://hackage.haskell.org/package/aeson) API.

category:             Text, Web, JSON
abi:                  80f4939ce65bea00c1ab01cff0f0c4bd
exposed:              True
exposed-modules:      Data.Aeson.Micro
hidden-modules:       Data.Aeson.Micro.Parser Data.Aeson.Micro.Scanner
import-dirs:          /usr/lib/ghc-9.0.2/site-local/microaeson-0.1.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/microaeson-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microaeson
hs-libraries:         HSmicroaeson-0.1.0.1-LwBFehKKOqM1ikuDRDjv1D
depends:
    array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    deepseq-1.4.5.0 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-microaeson/html/microaeson.haddock
haddock-html:         /usr/share/doc/haskell-microaeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
